import { doFetch } from '@/utils/doFetch';
import { Switch } from 'antd';
import fieldsDetail from '@/utils/fieldsDetail';

function getcolumns(ifs, actionRef) {
  return [
    {
      title: '供应商编号',
      dataIndex: 'supplierNo',
      key: 'supplierNo',
    },
    {
      title: '供应商名称',
      dataIndex: 'supplierName',
      key: 'supplierName',
      formItemProps: {
        rules: [
          {
            required: true,
            message: '此项为必填项',
          },
        ],
      },
    },
    {
      title: '纳税人识别号',
      dataIndex: 'taxpayerIdentificationNumber',
      key: 'taxpayerIdentificationNumber',
    },
    {
      title: '公司官网',
      dataIndex: 'companyWebsite',
      key: 'companyWebsite',
      hideInTable: true,
      search: false,
      formItemProps: {
        rules: [
          {
            required: false,
            message: '此项为必填项',
          },
        ],
      },
    },
    {
      title: '联系电话',
      dataIndex: 'phone',
      key: 'phone',
      formItemProps: {
        rules: [
          {
            required: false,
            message: '此项为必填项',
          },
        ],
      },
    },
    {
      title: '邮箱',
      dataIndex: 'companyEmail',
      key: 'companyEmail',
      formItemProps: {
        rules: [
          {
            required: false,
            message: '此项为必填项',
          },
        ],
      },
    },
    {
      title: '地址',
      dataIndex: 'address',
      key: 'address',
      search: false,
      formItemProps: {
        rules: [
          {
            required: false,
            message: '此项为必填项',
          },
        ],
      },
    },
    {
      title: '设备总数（租赁）',
      dataIndex: 'equipmentTotalNum',
      key: 'equipmentTotalNum',
      search: false,
      hideInForm: true
    },
    {
      title: '智能单元总数（租赁）',
      dataIndex: 'agentTotalNum',
      key: 'agentTotalNum',
      search: false,
      hideInForm: true
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      valueType: 'select',
      formItemProps: {
        rules: [
          {
            required: false,
            message: '此项为必填项',
          },
        ],
      },
      options: [
        {
          label: '启用',
          value: 1,
        },
        {
          label: '禁用',
          value: 2,
        },
      ],
      fieldProps: {
        disabled: ifs,
      },
      render: (text, row) => {
        return (
          <Switch
            checkedChildren="启用"
            unCheckedChildren="停用"
            checked={row?.status == 1}
            disabled={row?.statusChangeable == 1 ? false : true}
            onChange={() => {
              if (row?.status == 1) {
                doFetch({
                  url: '/lease/umEquipmentSupplier/startStop',
                  params: { id: row.id, status: '0' },
                }).then(() => {
                  actionRef.current.reload();
                });
              } else {
                doFetch({
                  url: '/lease/umEquipmentSupplier/startStop',
                  params: { id: row.id, status: '1' },
                }).then(() => {
                  actionRef.current.reload();
                });
              }
            }}
          />
        );
      },
    },
    {
      title: '评分',
      dataIndex: 'score',
      key: 'score',
      valueType: 'rate',
      search: false,
      searchValueType: 'digit',
      fieldProps: {
        defaultValue: 0,
        max: 5,
        precision: 1,
      },
      formItemProps: {
        rules: [
          {
            required: false,
            message: '此项为必填项',
          },
        ],
      },
    },
    {
      title: '备注',
      dataIndex: 'remark',
      key: 'remark',
      search: false,
      valueType: 'textarea',
      fieldProps: {
        placeholder: '请输入',
        showCount: true,
        maxLength: 255,
      },
      formItemProps: {
        rules: [
          {
            required: false,
            message: '此项为必填项',
          },
        ],
      },
    },
    {
      title: '联系信息',
      valueType: 'formList',
      dataIndex: 'list',
      key: 'supplierContactsList',
      initialValue: [
        {
          state: 'all',
          title: '标题',
        },
      ],
      colProps: {
        xs: 24,
        sm: 24,
      },
      columns: [
        {
          title: '联系人',
          dataIndex: 'contactsName',
          key: 'contactsName',
          formItemProps: {
            rules: [
              {
                required: true,
                message: '此项为必填项',
              },
            ],
          },
          colProps: {
            sm: 6,
          }
        },
        {
          title: '手机号码',
          dataIndex: 'mobilePhone',
          key: 'mobilePhone',
          colProps: {
            sm: 6,
          },
          formItemProps: {
            rules: [
              {
                required: false,
                message: '此项为必填项',
              },
              { pattern: new RegExp(/^1[3456789]\d{9}$/, 'g'), message: '' },
            ],
          },
        },
        {
          title: '邮箱',
          dataIndex: 'email',
          key: 'email',
          colProps: {
            sm: 6,
          },
        },
        {
          title: '职务',
          dataIndex: 'postName',
          key: 'postName',
          fieldProps: {
            placeholder: '请输入职务',
          },
          formItemProps: {
            rules: [
              {
                required: false,
                message: '此项为必填项',
              },
            ],
          },
          colProps: {
            sm: 6,
          },
        },
      ],
      search: false,
      hideInTable: true,
    },
  ];
}

export default getcolumns;
